@@ -2,9 +2,10 @@ package Alien::Libarchive::Installer;
 
 use strict;
 use warnings;
+use File::ShareDir qw( dist_dir );
 
 # ABSTRACT: Installer for libarchive
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 sub versions_available
@@ -67,6 +68,7 @@ sub build_requires
   my %prereqs = (
     'HTTP::Tiny'   => 0,
     'Archive::Tar' => 0,
+    'Alien::patch' => '0.08',
   );
   
   if($^O eq 'MSWin32')
@@ -271,6 +273,28 @@ sub build_install
       die "confused by multiple entries in the build root" if @list > 1;
       $list[0];
     };
+    
+    do {
+      $DB::single = 1;
+      my $share_dir = dist_dir('Alien-Libarchive-Installer');
+      my($version) = [File::Spec->splitpath(Cwd::getcwd())]->[2] =~ /libarchive-([0-9\.]+)/;
+      if($version)
+      {
+        my $patch = File::Spec->catdir($share_dir, 'patches', "$version.patch");
+        if(-r $patch)
+        {
+          require Alien::patch;
+          Alien::patch->import(); # add patch to the path if not already there.
+          my $patch_exe = Alien::patch->exe;
+          system "$patch_exe -p1 < $patch";
+          die "patch failed" if $?;
+        }
+      }
+      else
+      {
+        warn "unable to determine version number.";
+      }
+    };
   
     _msys(sub {
       my($make) = @_;
@@ -602,7 +626,7 @@ Alien::Libarchive::Installer - Installer for libarchive
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -633,7 +657,7 @@ Build.PL
  my $installer = eval {
    my $system_installer = Alien::Libarchive::Installer->system_install;
    die "we require 3.0.x or better"
-     if $system->version !~ /^([0-9]+)\./ && $1 >= 3;
+     if $system_installer->version !~ /^([0-9]+)\./ && $1 >= 3;
    $system_installer;
       # reasonably assumes that build_install will never download
       # a version older that 3.0
